# Changelog

<!--next-version-placeholder-->

## v0.11.1 (2021-01-31)
### Fix
* Use oauth3 login ([`487c7b4`](https://github.com/zabuldon/teslajsonpy/commit/487c7b4d3ff2cddf3bf3fdd099dc8a51ae2d4e5d))
* Fix header passing in __open ([`f193c64`](https://github.com/zabuldon/teslajsonpy/commit/f193c6439b3b6bc682e8884ec6950b44e0f0303c))

## v0.11.0 (2021-01-12)
### Feature
* Add charge limit soc ([#120](https://github.com/zabuldon/teslajsonpy/issues/120)) ([`441a72a`](https://github.com/zabuldon/teslajsonpy/commit/441a72a9f25b71cd9aecba10dab358a7f37f513f))

### Fix
* Tests.* (subpackage) exclusion from installs ([#116](https://github.com/zabuldon/teslajsonpy/issues/116)) ([`2d3ae90`](https://github.com/zabuldon/teslajsonpy/commit/2d3ae907506c8f59e32ef38fdd5b4902c2a7ab29))
